﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Windows.Input;
using PivotGridUsingFlatPivotTable.DataSource;

namespace PivotGridUsingFlatPivotTable.ViewModel
{
	public class TestViewModel : INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;

		private readonly ICommand loadTestDataCommand;
		private readonly IFlatPivotServerDataSource serverDataSource;
		private readonly FlatPivotDataSource flatPivotDataSource;

		public TestViewModel()
		{
			loadTestDataCommand = new DelegateCommand(LoadTestData);

			// This will produce the mock flat pivot table with test data
			serverDataSource = new MockFlatPivotServerDataSource();

			// I will attempt to bind the pivot-grid to this
			flatPivotDataSource = new FlatPivotDataSource();            
		    flatPivotDataSource.ConnectionSettings = new FlatPivotDataConnectionSettings(serverDataSource);
		}

		private void LoadTestData()
		{
            // setting a new settings instance will create new data provider for your data source
            // I have used MockFlatPivotServerDataSource2 modified class here
            flatPivotDataSource.ConnectionSettings = new FlatPivotDataConnectionSettings(new MockFlatPivotServerDataSource2());

            // reload the schema (all metadata is rebuild for the new settings object)
			flatPivotDataSource.LoadSchemaAsync();
		}

		public FlatPivotDataSource FlatPivotDataSource
		{
			get { return flatPivotDataSource; }
		}

		public ICommand LoadTestDataCommand
		{
			get { return loadTestDataCommand; }
		}
	}
}
